==> ralph-1.0.4.tar.gz: ralph-1.0.4/src/ralph/cmdb/integration/lib/fisheye.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from django.utils import simplejson as json
from django.conf import settings
from restkit import Resource, SimplePool, BasicAuth
from lxml import objectify
import logging
logger = logging.getLogger(__name__)

class Fisheye(object):
#    _instance = None
#    def __new__(cls, *args, **kwargs):
#        if not cls._instance:
#            cls._instance = super(Fisheye, cls).__new__(
#                                cls, *args, **kwargs)
#        return cls._instance

    def __init__(self):
        user = settings.FISHEYE_USER
        password = settings.FISHEYE_PASSWORD
        jira_url = settings.FISHEYE_URL
        self.project_name = settings.FISHEYE_PROJECT_NAME
        self.pool = SimplePool(keepalive=2)
        self.auth = BasicAuth(user, password)
        self.base_url = "%s/rest-service-fe" % jira_url

    def get_resource(self, resource_name):
        complete_url= "%s/%s" % (self.base_url , resource_name)
        logger.error("Calling " + complete_url)
        resource = Resource(complete_url, pool_instance=self.pool, filters=[self.auth])
        return resource

    def call_resource(self, resource_name, params):
        """ call GET method and returns json/xml results"""
        resource = self.get_resource(resource_name)
        response = resource.get(headers={'Content-Type' : 'application/json'})
        s = response.body_string()
        if response.headers.get('content-type').find('application/xml')>=0:
            ret = objectify.fromstring(s)
        elif response.headers.get('content-type').find('application/json')>=0:
            ret = json.loads(s)
        else:
            ret = s
        return ret

    def get_details(self, change_id):
        """ Returns changeset details """
        resource_name = "revisionData-v1/changeset/%(project)s/%(changeset)s" % dict(
                project=self.project_name,
                changeset=change_id\
        )
        return self.call_resource(resource_name, params={})

    def get_changes(self, params={}):
        """ Returns list of changesets """
        resource_name = "revisionData-v1/changesetList/%s?media=json" % self.project_name
        return self.call_resource(resource_name, params)

==> ralph-1.0.5.tar.gz: ralph-1.0.5/src/ralph/cmdb/integration/lib/fisheye.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from django.utils import simplejson as json
from django.conf import settings
from restkit import Resource, SimplePool, BasicAuth
from lxml import objectify
import logging


logger = logging.getLogger(__name__)


class Fisheye(object):
    def __init__(self):
        user = settings.FISHEYE_USER
        password = settings.FISHEYE_PASSWORD
        jira_url = settings.FISHEYE_URL
        self.project_name = settings.FISHEYE_PROJECT_NAME
        self.pool = SimplePool(keepalive=2)
        self.auth = BasicAuth(user, password)
        self.base_url = "%s/rest-service-fe" % jira_url

    def get_resource(self, resource_name):
        complete_url= "%s/%s" % (self.base_url , resource_name)
        logger.debug("Calling " + complete_url)
        resource = Resource(complete_url, pool_instance=self.pool, filters=[self.auth])
        return resource

    def call_resource(self, resource_name, params):
        """ call GET method and returns json/xml results"""
        resource = self.get_resource(resource_name)
        response = resource.get(headers={'Content-Type' : 'application/json'})
        s = response.body_string()
        if response.headers.get('content-type').find('application/xml')>=0:
            ret = objectify.fromstring(s)
        elif response.headers.get('content-type').find('application/json')>=0:
            ret = json.loads(s)
        else:
            ret = s
        return ret

    def get_details(self, change_id):
        """ Returns changeset details """
        resource_name = "revisionData-v1/changeset/%(project)s/%(changeset)s" % dict(
                project=self.project_name,
                changeset=change_id\
        )
        return self.call_resource(resource_name, params={})

    def get_changes(self, params={}):
        """ Returns list of changesets """
        resource_name = "revisionData-v1/changesetList/%s?media=json" % self.project_name
        return self.call_resource(resource_name, params)
